@@ -21,7 +21,7 @@ class AbjadAttachment(abc.ABC):
 
     @classmethod
     def get_class_name(cls):
-        return tools.class_name_to_object_name(cls.__name__)
+        return tools.camel_case_to_snake_case(cls.__name__)
 
     @classmethod
     def from_indicator_collection(
@@ -72,7 +72,7 @@ class ToggleAttachment(AbjadAttachment):
     @abc.abstractmethod
     def process_leaf(
         self, leaf: abjad.Leaf, previous_attachment: typing.Optional["AbjadAttachment"]
-    ) -> typing.Union[abjad.Leaf, typing.Iterable[abjad.Leaf]]:
+    ) -> typing.Union[abjad.Leaf, typing.Sequence[abjad.Leaf]]:
         raise NotImplementedError()
 
     def process_leaves(
@@ -134,22 +134,22 @@ class BangEachAttachment(BangAttachment):
     @abc.abstractmethod
     def process_leaf(
         self, leaf: abjad.Leaf
-    ) -> typing.Union[abjad.Leaf, typing.Iterable[abjad.Leaf]]:
+    ) -> typing.Union[abjad.Leaf, typing.Sequence[abjad.Leaf]]:
         raise NotImplementedError()
 
     def process_first_leaf(
         self, leaf: abjad.Leaf
-    ) -> typing.Union[abjad.Leaf, typing.Iterable[abjad.Leaf]]:
+    ) -> typing.Union[abjad.Leaf, typing.Sequence[abjad.Leaf]]:
         return self.process_leaf(leaf)
 
     def process_last_leaf(
         self, leaf: abjad.Leaf
-    ) -> typing.Union[abjad.Leaf, typing.Iterable[abjad.Leaf]]:
+    ) -> typing.Union[abjad.Leaf, typing.Sequence[abjad.Leaf]]:
         return self.process_leaf(leaf)
 
     def process_central_leaf(
         self, leaf: abjad.Leaf
-    ) -> typing.Union[abjad.Leaf, typing.Iterable[abjad.Leaf]]:
+    ) -> typing.Union[abjad.Leaf, typing.Sequence[abjad.Leaf]]:
         return self.process_leaf(leaf)
 
 
@@ -157,22 +157,22 @@ class BangFirstAttachment(BangAttachment):
     @abc.abstractmethod
     def process_leaf(
         self, leaf: abjad.Leaf
-    ) -> typing.Union[abjad.Leaf, typing.Iterable[abjad.Leaf]]:
+    ) -> typing.Union[abjad.Leaf, typing.Sequence[abjad.Leaf]]:
         raise NotImplementedError()
 
     def process_first_leaf(
         self, leaf: abjad.Leaf
-    ) -> typing.Union[abjad.Leaf, typing.Iterable[abjad.Leaf]]:
+    ) -> typing.Union[abjad.Leaf, typing.Sequence[abjad.Leaf]]:
         return self.process_leaf(leaf)
 
     def process_last_leaf(
         self, leaf: abjad.Leaf
-    ) -> typing.Union[abjad.Leaf, typing.Iterable[abjad.Leaf]]:
+    ) -> typing.Union[abjad.Leaf, typing.Sequence[abjad.Leaf]]:
         return leaf
 
     def process_central_leaf(
         self, leaf: abjad.Leaf
-    ) -> typing.Union[abjad.Leaf, typing.Iterable[abjad.Leaf]]:
+    ) -> typing.Union[abjad.Leaf, typing.Sequence[abjad.Leaf]]:
         return leaf
 
 
@@ -180,7 +180,7 @@ class BangLastAttachment(BangAttachment):
     @abc.abstractmethod
     def process_leaf(
         self, leaf: abjad.Leaf
-    ) -> typing.Union[abjad.Leaf, typing.Iterable[abjad.Leaf]]:
+    ) -> typing.Union[abjad.Leaf, typing.Sequence[abjad.Leaf]]:
         raise NotImplementedError()
 
     def process_first_leaf(self, leaf: abjad.Leaf) -> abjad.Leaf:
@@ -205,25 +205,44 @@ class BangLastAttachment(BangAttachment):
 
 
 class Arpeggio(playing_indicators.Arpeggio, BangFirstAttachment):
+    _string_to_direction = {
+        "up": abjad.enums.Up,
+        "down": abjad.enums.Down,
+        "center": abjad.enums.Center,
+        "^": abjad.enums.Up,
+        "_": abjad.enums.Down,
+    }
+
     def process_leaf(
         self, leaf: abjad.Leaf
-    ) -> typing.Union[abjad.Leaf, typing.Iterable[abjad.Leaf]]:
-        abjad.attach(abjad.Arpeggio(direction=self.direction), leaf)
+    ) -> typing.Union[abjad.Leaf, typing.Sequence[abjad.Leaf]]:
+        direction = self.direction
+        if direction in self._string_to_direction:
+            direction = self._string_to_direction[direction]
+        abjad.attach(abjad.Arpeggio(direction=direction), leaf)
         return leaf
 
 
 class Articulation(playing_indicators.Articulation, BangEachAttachment):
     def process_leaf(
         self, leaf: abjad.Leaf
-    ) -> typing.Union[abjad.Leaf, typing.Iterable[abjad.Leaf]]:
+    ) -> typing.Union[abjad.Leaf, typing.Sequence[abjad.Leaf]]:
         abjad.attach(abjad.Articulation(self.name), leaf)
         return leaf
 
 
+class Trill(playing_indicators.Trill, BangFirstAttachment):
+    def process_leaf(
+        self, leaf: abjad.Leaf
+    ) -> typing.Union[abjad.Leaf, typing.Sequence[abjad.Leaf]]:
+        abjad.attach(abjad.Articulation("trill"), leaf)
+        return leaf
+
+
 class Tremolo(playing_indicators.Tremolo, BangEachAttachment):
     def process_leaf(
         self, leaf: abjad.Leaf
-    ) -> typing.Union[abjad.Leaf, typing.Iterable[abjad.Leaf]]:
+    ) -> typing.Union[abjad.Leaf, typing.Sequence[abjad.Leaf]]:
         abjad.attach(
             abjad.StemTremolo(self.n_flags * (2 ** leaf.written_duration.flag_count)),
             leaf,
@@ -277,7 +296,7 @@ class ArtificalHarmonic(playing_indicators.ArtificalHarmonic, BangEachAttachment
 
     def process_leaf(
         self, leaf: abjad.Leaf
-    ) -> typing.Union[abjad.Leaf, typing.Iterable[abjad.Leaf]]:
+    ) -> typing.Union[abjad.Leaf, typing.Sequence[abjad.Leaf]]:
         leaf, is_attachable = ArtificalHarmonic._convert_and_test_leaf(leaf)
         if is_attachable:
             first_pitch = leaf.note_heads[0].written_pitch
@@ -308,7 +327,7 @@ class PreciseNaturalHarmonic(
 
     def process_leaf(
         self, leaf: abjad.Leaf
-    ) -> typing.Union[abjad.Leaf, typing.Iterable[abjad.Leaf]]:
+    ) -> typing.Union[abjad.Leaf, typing.Sequence[abjad.Leaf]]:
         if isinstance(leaf, (abjad.Chord, abjad.Note)):
             leaf = PreciseNaturalHarmonic._convert_leaf(leaf)
             leaf.written_pitches = abjad.PitchSegment(
@@ -330,12 +349,31 @@ class PreciseNaturalHarmonic(
 
 
 class StringContactPoint(playing_indicators.StringContactPoint, ToggleAttachment):
-    def process_leaf(
-        self, leaf: abjad.Leaf, previous_attachment: typing.Optional["AbjadAttachment"]
-    ) -> typing.Union[abjad.Leaf, typing.Iterable[abjad.Leaf]]:
-        string_contact_point_markup = abjad.StringContactPoint(
-            self.contact_point
-        ).markup
+    def __init__(self, *args, **kwargs):
+        super().__init__(*args, **kwargs)
+
+        # Extend abjad with custom string contact points
+        class StringContactPoint(abjad.StringContactPoint):
+            _contact_point = abjad.StringContactPoint._contact_points + tuple(
+                attachments_constants.CUSTOM_STRING_CONTACT_POINT_DICT.keys()
+            )
+            _contact_point_abbreviations = dict(
+                abjad.StringContactPoint._contact_point_abbreviations,
+                **attachments_constants.CUSTOM_STRING_CONTACT_POINT_DICT,
+            )
+
+        self._string_contact_point_class = StringContactPoint
+        self._abbreviation_to_string_contact_point = {
+            abbreviation: full_name
+            for full_name, abbreviation in StringContactPoint._contact_point_abbreviations.items()
+        }
+
+    def _attach_string_contact_point(
+        self,
+        leaf: abjad.Leaf,
+        previous_attachment: typing.Optional["AbjadAttachment"],
+        string_contact_point_markup: abjad.Markup,
+    ):
         if previous_attachment:
             if previous_attachment.contact_point == "pizzicato":  # type: ignore
                 string_contact_point_markup = abjad.Markup(
@@ -359,6 +397,26 @@ class StringContactPoint(playing_indicators.StringContactPoint, ToggleAttachment
             ),
             leaf,
         )
+
+    def process_leaf(
+        self, leaf: abjad.Leaf, previous_attachment: typing.Optional["AbjadAttachment"]
+    ) -> typing.Union[abjad.Leaf, typing.Sequence[abjad.Leaf]]:
+        contact_point = self.contact_point
+        if contact_point in self._abbreviation_to_string_contact_point:
+            contact_point = self._abbreviation_to_string_contact_point[contact_point]
+        try:
+            string_contact_point_markup = self._string_contact_point_class(
+                contact_point
+            ).markup
+        except AssertionError:
+            warnings.warn(
+                f"Can't find contact point '{self.contact_point}' "
+                f"in '{self._string_contact_point_class._contact_point_abbreviations}'!"
+            )
+        else:
+            self._attach_string_contact_point(
+                leaf, previous_attachment, string_contact_point_markup
+            )
         return leaf
 
     def process_leaves(
@@ -376,7 +434,7 @@ class StringContactPoint(playing_indicators.StringContactPoint, ToggleAttachment
 class Pedal(playing_indicators.Pedal, ToggleAttachment):
     def process_leaf(
         self, leaf: abjad.Leaf, previous_attachment: typing.Optional["AbjadAttachment"]
-    ) -> typing.Union[abjad.Leaf, typing.Iterable[abjad.Leaf]]:
+    ) -> typing.Union[abjad.Leaf, typing.Sequence[abjad.Leaf]]:
         if self.pedal_activity:
             pedal_class = abjad.StartPianoPedal
         else:
@@ -400,7 +458,7 @@ class Pedal(playing_indicators.Pedal, ToggleAttachment):
 class Hairpin(playing_indicators.Hairpin, ToggleAttachment):
     def process_leaf(
         self, leaf: abjad.Leaf, previous_attachment: typing.Optional["AbjadAttachment"]
-    ) -> typing.Union[abjad.Leaf, typing.Iterable[abjad.Leaf]]:
+    ) -> typing.Union[abjad.Leaf, typing.Sequence[abjad.Leaf]]:
         if self.symbol == "!":
             abjad.attach(
                 abjad.StopHairpin(),
@@ -417,7 +475,7 @@ class Hairpin(playing_indicators.Hairpin, ToggleAttachment):
 class BartokPizzicato(parameters_abc.ExplicitPlayingIndicator, BangFirstAttachment):
     def process_leaf(
         self, leaf: abjad.Leaf
-    ) -> typing.Union[abjad.Leaf, typing.Iterable[abjad.Leaf]]:
+    ) -> typing.Union[abjad.Leaf, typing.Sequence[abjad.Leaf]]:
         abjad.attach(
             abjad.LilyPondLiteral("\\snappizzicato", format_slot="after"),
             leaf,
@@ -428,7 +486,7 @@ class BartokPizzicato(parameters_abc.ExplicitPlayingIndicator, BangFirstAttachme
 class BreathMark(parameters_abc.ExplicitPlayingIndicator, BangFirstAttachment):
     def process_leaf(
         self, leaf: abjad.Leaf
-    ) -> typing.Union[abjad.Leaf, typing.Iterable[abjad.Leaf]]:
+    ) -> typing.Union[abjad.Leaf, typing.Sequence[abjad.Leaf]]:
         abjad.attach(
             abjad.LilyPondLiteral("\\breathe", format_slot="before"),
             leaf,
@@ -439,7 +497,7 @@ class BreathMark(parameters_abc.ExplicitPlayingIndicator, BangFirstAttachment):
 class Fermata(playing_indicators.Fermata, BangFirstAttachment):
     def process_leaf(
         self, leaf: abjad.Leaf
-    ) -> typing.Union[abjad.Leaf, typing.Iterable[abjad.Leaf]]:
+    ) -> typing.Union[abjad.Leaf, typing.Sequence[abjad.Leaf]]:
         abjad.attach(
             abjad.Fermata(self.fermata_type),
             leaf,
@@ -450,7 +508,7 @@ class Fermata(playing_indicators.Fermata, BangFirstAttachment):
 class NaturalHarmonic(parameters_abc.ExplicitPlayingIndicator, BangFirstAttachment):
     def process_leaf(
         self, leaf: abjad.Leaf
-    ) -> typing.Union[abjad.Leaf, typing.Iterable[abjad.Leaf]]:
+    ) -> typing.Union[abjad.Leaf, typing.Sequence[abjad.Leaf]]:
         abjad.attach(
             abjad.LilyPondLiteral("\\flageolet", directed="up", format_slot="after"),
             leaf,
@@ -462,7 +520,7 @@ class NaturalHarmonic(parameters_abc.ExplicitPlayingIndicator, BangFirstAttachme
 class Prall(parameters_abc.ExplicitPlayingIndicator, BangFirstAttachment):
     def process_leaf(
         self, leaf: abjad.Leaf
-    ) -> typing.Union[abjad.Leaf, typing.Iterable[abjad.Leaf]]:
+    ) -> typing.Union[abjad.Leaf, typing.Sequence[abjad.Leaf]]:
         abjad.attach(
             abjad.LilyPondLiteral("^\\prall", format_slot="after"),
             leaf,
@@ -473,7 +531,7 @@ class Prall(parameters_abc.ExplicitPlayingIndicator, BangFirstAttachment):
 class Tie(parameters_abc.ExplicitPlayingIndicator, BangLastAttachment):
     def process_leaf(
         self, leaf: abjad.Leaf
-    ) -> typing.Union[abjad.Leaf, typing.Iterable[abjad.Leaf]]:
+    ) -> typing.Union[abjad.Leaf, typing.Sequence[abjad.Leaf]]:
         if isinstance(leaf, (abjad.Chord, abjad.Note)):
             abjad.attach(
                 abjad.Tie(),
@@ -482,13 +540,39 @@ class Tie(parameters_abc.ExplicitPlayingIndicator, BangLastAttachment):
         return leaf
 
 
+class DurationLineTriller(parameters_abc.ExplicitPlayingIndicator, BangEachAttachment):
+    def process_leaf(
+        self, leaf: abjad.Leaf
+    ) -> typing.Union[abjad.Leaf, typing.Sequence[abjad.Leaf]]:
+        if isinstance(leaf, (abjad.Chord, abjad.Note)):
+            abjad.attach(
+                abjad.LilyPondLiteral("\\once \\override DurationLine.style = #'trill"),
+                leaf,
+            )
+        return leaf
+
+
+class DurationLineDashed(parameters_abc.ExplicitPlayingIndicator, BangEachAttachment):
+    def process_leaf(
+        self, leaf: abjad.Leaf
+    ) -> typing.Union[abjad.Leaf, typing.Sequence[abjad.Leaf]]:
+        if isinstance(leaf, (abjad.Chord, abjad.Note)):
+            abjad.attach(
+                abjad.LilyPondLiteral(
+                    "\\once \\override DurationLine.style = #'dashed-line"
+                ),
+                leaf,
+            )
+        return leaf
+
+
 class Glissando(parameters_abc.ExplicitPlayingIndicator, BangLastAttachment):
     thickness = 3
     minimum_length = 5
 
     def process_leaf(
         self, leaf: abjad.Leaf
-    ) -> typing.Union[abjad.Leaf, typing.Iterable[abjad.Leaf]]:
+    ) -> typing.Union[abjad.Leaf, typing.Sequence[abjad.Leaf]]:
         abjad.attach(
             abjad.LilyPondLiteral(
                 "\\override Glissando.thickness = #'{}".format(self.thickness)
@@ -509,9 +593,13 @@ class Glissando(parameters_abc.ExplicitPlayingIndicator, BangLastAttachment):
             abjad.LilyPondLiteral("\\override Glissando.after-line-breaking = ##t"),
             leaf,
         )
-        cmd = "\\override "
-        cmd += "Glissando.springs-and-rods = #ly:spanner::set-spacing-rods"
-        abjad.attach(abjad.LilyPondLiteral(cmd), leaf)
+        # Prevent duration line from getting printed when we print a glissando
+        abjad.attach(
+            abjad.LilyPondLiteral("\\once \\override DurationLine.style = #'none"), leaf
+        )
+        command = "\\override "
+        command += "Glissando.springs-and-rods = #ly:spanner::set-spacing-rods"
+        abjad.attach(abjad.LilyPondLiteral(command), leaf)
         abjad.attach(
             abjad.Glissando(allow_ties=True),
             leaf,
@@ -519,10 +607,52 @@ class Glissando(parameters_abc.ExplicitPlayingIndicator, BangLastAttachment):
         return leaf
 
 
+class BendAfter(playing_indicators.BendAfter, BangLastAttachment):
+    def _attach_bend_after_to_note(self, note: abjad.Note):
+        abjad.attach(
+            abjad.LilyPondLiteral(
+                "\\once \\override BendAfter.thickness = #'{}".format(self.thickness)
+            ),
+            note,
+        )
+        abjad.attach(
+            abjad.LilyPondLiteral(
+                f"\\once \\override BendAfter.minimum-length = #{self.minimum_length}"
+            ),
+            note,
+        )
+        abjad.attach(
+            abjad.LilyPondLiteral("\\once \\override DurationLine.style = #'none"), note
+        )
+        abjad.attach(abjad.BendAfter(bend_amount=self.bend_amount), note)
+
+    def process_leaf(
+        self, leaf: abjad.Leaf
+    ) -> typing.Union[abjad.Leaf, typing.Sequence[abjad.Leaf]]:
+        if isinstance(leaf, abjad.Chord):
+            indicator_list = abjad.get.indicators(leaf)
+            container = abjad.Container([], simultaneous=True)
+            for note_head in leaf.note_heads:
+                note = abjad.Note("c", leaf.written_duration)
+                note.note_head._written_pitch = note_head.written_pitch
+                self._attach_bend_after_to_note(note)
+                for indicator in indicator_list:
+                    abjad.attach(indicator, note)
+                voice = abjad.Voice([note])
+                container.append(voice)
+
+            return container
+
+        elif isinstance(leaf, abjad.Note):
+            self._attach_bend_after_to_note(leaf)
+
+        return leaf
+
+
 class LaissezVibrer(parameters_abc.ExplicitPlayingIndicator, BangLastAttachment):
     def process_leaf(
         self, leaf: abjad.Leaf
-    ) -> typing.Union[abjad.Leaf, typing.Iterable[abjad.Leaf]]:
+    ) -> typing.Union[abjad.Leaf, typing.Sequence[abjad.Leaf]]:
         abjad.attach(
             abjad.LaissezVibrer(),
             leaf,
@@ -533,7 +663,7 @@ class LaissezVibrer(parameters_abc.ExplicitPlayingIndicator, BangLastAttachment)
 class BarLine(notation_indicators.BarLine, BangLastAttachment):
     def process_leaf(
         self, leaf: abjad.Leaf
-    ) -> typing.Union[abjad.Leaf, typing.Iterable[abjad.Leaf]]:
+    ) -> typing.Union[abjad.Leaf, typing.Sequence[abjad.Leaf]]:
         abjad.attach(
             abjad.BarLine(self.abbreviation),
             leaf,
@@ -544,7 +674,7 @@ class BarLine(notation_indicators.BarLine, BangLastAttachment):
 class Clef(notation_indicators.Clef, BangFirstAttachment):
     def process_leaf(
         self, leaf: abjad.Leaf
-    ) -> typing.Union[abjad.Leaf, typing.Iterable[abjad.Leaf]]:
+    ) -> typing.Union[abjad.Leaf, typing.Sequence[abjad.Leaf]]:
         abjad.attach(
             abjad.Clef(self.name),
             leaf,
@@ -555,7 +685,7 @@ class Clef(notation_indicators.Clef, BangFirstAttachment):
 class Ottava(notation_indicators.Ottava, ToggleAttachment):
     def process_leaf(
         self, leaf: abjad.Leaf, previous_attachment: typing.Optional["AbjadAttachment"]
-    ) -> typing.Union[abjad.Leaf, typing.Iterable[abjad.Leaf]]:
+    ) -> typing.Union[abjad.Leaf, typing.Sequence[abjad.Leaf]]:
         abjad.attach(
             abjad.Ottava(self.n_octaves, format_slot="before"),
             leaf,
@@ -577,7 +707,7 @@ class Ottava(notation_indicators.Ottava, ToggleAttachment):
 class Markup(notation_indicators.Markup, BangFirstAttachment):
     def process_leaf(
         self, leaf: abjad.Leaf
-    ) -> typing.Union[abjad.Leaf, typing.Iterable[abjad.Leaf]]:
+    ) -> typing.Union[abjad.Leaf, typing.Sequence[abjad.Leaf]]:
         abjad.attach(
             abjad.Markup(self.content, direction=self.direction),
             leaf,
@@ -588,7 +718,7 @@ class Markup(notation_indicators.Markup, BangFirstAttachment):
 class RehearsalMark(notation_indicators.RehearsalMark, BangFirstAttachment):
     def process_leaf(
         self, leaf: abjad.Leaf
-    ) -> typing.Union[abjad.Leaf, typing.Iterable[abjad.Leaf]]:
+    ) -> typing.Union[abjad.Leaf, typing.Sequence[abjad.Leaf]]:
         abjad.attach(
             abjad.RehearsalMark(markup=self.markup),
             leaf,
@@ -599,7 +729,7 @@ class RehearsalMark(notation_indicators.RehearsalMark, BangFirstAttachment):
 class MarginMarkup(notation_indicators.MarginMarkup, BangFirstAttachment):
     def process_leaf(
         self, leaf: abjad.Leaf
-    ) -> typing.Union[abjad.Leaf, typing.Iterable[abjad.Leaf]]:
+    ) -> typing.Union[abjad.Leaf, typing.Sequence[abjad.Leaf]]:
         command = "\\set {}.instrumentName = \\markup ".format(self.context)
         command += "{ " + self.content + " }"  # type: ignore
         abjad.attach(
@@ -643,7 +773,7 @@ class Ornamentation(playing_indicators.Ornamentation, BangFirstAttachment):
 
     def process_leaf(
         self, leaf: abjad.Leaf
-    ) -> typing.Union[abjad.Leaf, typing.Iterable[abjad.Leaf]]:
+    ) -> typing.Union[abjad.Leaf, typing.Sequence[abjad.Leaf]]:
         abjad.attach(self._make_markup(), leaf)
         return leaf
 
@@ -668,7 +798,7 @@ class Dynamic(ToggleAttachment):
 
     def process_leaf(
         self, leaf: abjad.Leaf, previous_attachment: typing.Optional["AbjadAttachment"]
-    ) -> typing.Union[abjad.Leaf, typing.Iterable[abjad.Leaf]]:
+    ) -> typing.Union[abjad.Leaf, typing.Sequence[abjad.Leaf]]:
         abjad.attach(abjad.Dynamic(self.dynamic_indicator), leaf)
         return leaf
 
@@ -710,7 +840,7 @@ class Tempo(BangFirstAttachment):
 
     def process_leaf(
         self, leaf: abjad.Leaf
-    ) -> typing.Union[abjad.Leaf, typing.Iterable[abjad.Leaf]]:
+    ) -> typing.Union[abjad.Leaf, typing.Sequence[abjad.Leaf]]:
         self._attach_metronome_mark(leaf)
 
         if self.dynamic_change_indication is not None:
@@ -739,7 +869,7 @@ class DynamicChangeIndicationStop(BangFirstAttachment):
 
     def process_leaf(
         self, leaf: abjad.Leaf
-    ) -> typing.Union[abjad.Leaf, typing.Iterable[abjad.Leaf]]:
+    ) -> typing.Union[abjad.Leaf, typing.Sequence[abjad.Leaf]]:
         abjad.attach(abjad.StopTextSpan(), leaf)
         return leaf
 
@@ -764,7 +894,7 @@ class GraceNoteSequentialEvent(BangFirstAttachment):
 
     def process_leaf(
         self, leaf: abjad.Leaf
-    ) -> typing.Union[abjad.Leaf, typing.Iterable[abjad.Leaf]]:
+    ) -> typing.Union[abjad.Leaf, typing.Sequence[abjad.Leaf]]:
         for (
             indicator_to_detach
         ) in attachments_constants.INDICATORS_TO_DETACH_FROM_MAIN_LEAF_AT_GRACE_NOTES:
@@ -794,6 +924,6 @@ class AfterGraceNoteSequentialEvent(BangLastAttachment):
 
     def process_leaf(
         self, leaf: abjad.Leaf
-    ) -> typing.Union[abjad.Leaf, typing.Iterable[abjad.Leaf]]:
+    ) -> typing.Union[abjad.Leaf, typing.Sequence[abjad.Leaf]]:
         abjad.attach(self._after_grace_note_sequential_event, leaf)
         return leaf
