@@ -74,98 +74,49 @@ class Tremolo(parameters.abc.ImplicitPlayingIndicator):
 @dataclasses.dataclass()
 class Articulation(parameters.abc.ImplicitPlayingIndicator):
     name: typing.Optional[
-        typing.Literal[
-            # Copy/paste from
-            # https://abjad.github.io/_modules/abjad/indicators/Articulation.html
-            "accent",
-            "marcato",
-            "staccatissimo",
-            "espressivo",
-            "staccato",
-            "tenuto",
-            "portato",
-            "upbow",
-            "downbow",
-            "flageolet",
-            "thumb",
-            "lheel",
-            "rheel",
-            "ltoe",
-            "rtoe",
-            "open",
-            "halfopen",
-            "snappizzicato",
-            "stopped",
-            "turn",
-            "reverseturn",
-            "trill",
-            "prall",
-            "mordent",
-            "prallprall",
-            "prallmordent",
-            "upprall",
-            "downprall",
-            "upmordent",
-            "downmordent",
-            "pralldown",
-            "prallup",
-            "lineprall",
-            "signumcongruentiae",
-            "shortfermata",
-            "fermata",
-            "longfermata",
-            "verylongfermata",
-            "segno",
-            "coda",
-            "varcoda",
-            "^",
-            "+",
-            "-",
-            "|",
-            ">",
-            ".",
-            "_",
-        ]
+        parameters.playing_indicators_constants.ARTICULATION_LITERAL
     ] = None
 
 
 @dataclasses.dataclass()
 class Arpeggio(parameters.abc.ImplicitPlayingIndicator):
-    direction: typing.Optional[typing.Literal["up", "down"]] = None
+    direction: typing.Optional[
+        parameters.playing_indicators_constants.DIRECTION_LITERAL
+    ] = None
 
 
 @dataclasses.dataclass()
 class Pedal(parameters.abc.ImplicitPlayingIndicator):
-    # Pedal types copied from
-    # https://abjad.github.io/_modules/abjad/indicators/StartPianoPedal.html
-    pedal_type: typing.Optional[typing.Literal["sustain", "sostenuto", "corda"]] = None
+    pedal_type: typing.Optional[
+        parameters.playing_indicators_constants.PEDAL_TYPE_LITERAL
+    ] = None
     pedal_activity: typing.Optional[bool] = True
 
 
 @dataclasses.dataclass()
 class StringContactPoint(parameters.abc.ImplicitPlayingIndicator):
     contact_point: typing.Optional[
-        typing.Literal[
-            # Copied from
-            # https://abjad.github.io/_modules/abjad/indicators/StringContactPoint.html#StringContactPoint
-            "dietro ponticello",
-            "molto sul ponticello",
-            "molto sul tasto",
-            "ordinario",
-            "pizzicato",
-            "ponticello",
-            "sul ponticello",
-            "sul tasto",
-        ]
+        parameters.playing_indicators_constants.CONTACT_POINT_LITERAL
     ] = None
 
 
 @dataclasses.dataclass()
 class Ornamentation(parameters.abc.ImplicitPlayingIndicator):
-    direction: typing.Optional[typing.Literal["up", "down"]] = None
+    direction: typing.Optional[
+        parameters.playing_indicators_constants.DIRECTION_LITERAL
+    ] = None
     n_times: int = 1
 
 
+@dataclasses.dataclass()
+class BendAfter(parameters.abc.ImplicitPlayingIndicator):
+    # Content parameters
+    bend_amount: typing.Optional[float] = None
+    # Presentation parameters
+    minimum_length: typing.Optional[float] = 3
+    thickness: typing.Optional[float] = 3
+
+
 @dataclasses.dataclass()
 class ArtificalHarmonic(parameters.abc.ImplicitPlayingIndicator):
     n_semitones: typing.Optional[int] = None
@@ -182,18 +133,20 @@ class PreciseNaturalHarmonic(parameters.abc.ImplicitPlayingIndicator):
 @dataclasses.dataclass()
 class Fermata(parameters.abc.ImplicitPlayingIndicator):
     fermata_type: typing.Optional[
-        typing.Literal[
-            "shortfermata",
-            "fermata",
-            "longfermata",
-            "verylongfermata",
-        ]
+        parameters.playing_indicators_constants.FERMATA_TYPE_LITERAL
     ] = None
 
 
 @dataclasses.dataclass()
 class Hairpin(parameters.abc.ImplicitPlayingIndicator):
-    symbol: typing.Optional[typing.Literal["<", ">", "!"]] = None
+    symbol: typing.Optional[
+        parameters.playing_indicators_constants.HAIRPIN_SYMBOL_LITERAL
+    ] = None
+
+
+@dataclasses.dataclass()
+class Trill(parameters.abc.ImplicitPlayingIndicator):
+    pitch: typing.Optional[parameters.abc.Pitch] = None
 
 
 @dataclasses.dataclass
@@ -210,9 +163,16 @@ class PlayingIndicatorCollection(
     bartok_pizzicato: parameters.abc.PlayingIndicator = dataclasses.field(
         default_factory=parameters.abc.ExplicitPlayingIndicator
     )
+    bend_after: BendAfter = dataclasses.field(default_factory=BendAfter)
     breath_mark: parameters.abc.PlayingIndicator = dataclasses.field(
         default_factory=parameters.abc.ExplicitPlayingIndicator
     )
+    duration_line_dashed: parameters.abc.PlayingIndicator = dataclasses.field(
+        default_factory=parameters.abc.ExplicitPlayingIndicator
+    )
+    duration_line_triller: parameters.abc.PlayingIndicator = dataclasses.field(
+        default_factory=parameters.abc.ExplicitPlayingIndicator
+    )
     fermata: Fermata = dataclasses.field(default_factory=Fermata)
     glissando: parameters.abc.PlayingIndicator = dataclasses.field(
         default_factory=parameters.abc.ExplicitPlayingIndicator
@@ -239,6 +199,7 @@ class PlayingIndicatorCollection(
         default_factory=parameters.abc.ExplicitPlayingIndicator
     )
     tremolo: Tremolo = dataclasses.field(default_factory=Tremolo)
+    trill: Trill = dataclasses.field(default_factory=Trill)
 
     def __setattr__(self, parameter_name: str, value: bool):
         """Overriding default behaviour to allow syntactic sugar.
@@ -263,7 +224,9 @@ class PlayingIndicatorCollection(
             if isinstance(playing_indicator, parameters.abc.ExplicitPlayingIndicator):
                 playing_indicator.is_active = bool(value)
             else:
-                message = f"Can't override frozen property (playing indicator) '{playing_indicator}'!"
-                raise dataclasses.FrozenInstanceError(message)
+                raise dataclasses.FrozenInstanceError(
+                    "Can't override frozen property (playing indicator)"
+                    f" '{playing_indicator}'!"
+                )
         else:
             super().__setattr__(parameter_name, value)
