@@ -26,6 +26,7 @@ __all__ = (
     "get_nested_item_from_indices",
     "set_nested_item_from_indices",
     "find_numbers_which_sums_up_to",
+    # call_function_except_attribute_error  # not for public use
 )
 
 
@@ -219,9 +220,7 @@ def import_module_if_dependencies_have_been_installed(
     module: str, dependencies: tuple[str, ...], import_class: bool = False
 ) -> None:
     for dependency in dependencies:
-        try:
-            importlib.import_module(dependency)
-        except ImportError:
+        if not importlib.util.find_spec(dependency):
             message = (
                 "Can't load module '{0}'. Install dependency '{1}' if you want to use"
                 " '{0}'.".format(module, dependency)
@@ -299,15 +298,21 @@ def cyclic_permutations(sequence: typing.Sequence[typing.Any]) -> typing.Generat
     )
 
 
-def class_name_to_object_name(class_name: str) -> str:
+def camel_case_to_snake_case(camel_case_string: str) -> str:
+    """Transform camel case formatted string to snake case.
+
+    :param camel_case_string: String which is formatted using
+        camel case (no whitespace, but upper letters at
+        new word start).
+    :return: string formatted using snake case
+
+    **Example:** MyClassName -> my_class_name
     """
 
-    MyClassName -> my_class_name
-    """
     characters = []
 
     is_first = True
-    for character in class_name:
+    for character in camel_case_string:
         if character.isupper():
             character = character.lower()
             if not is_first:
@@ -438,3 +443,27 @@ def find_numbers_which_sums_up_to(
             ]
         )
     return tuple(numbers)
+
+
+def call_function_except_attribute_error(
+    function: typing.Callable[[typing.Any], typing.Any],
+    argument: typing.Any,
+    exception_value: typing.Any,
+) -> typing.Any:
+    """Run a function with argument as input
+
+    :param function: The function to be called.
+    :param argument: The argument with which the function shall be called.
+    :param exception_value: The alternative value if the function call raises an
+        `AttributeError`.
+    :return: Return :obj:`exception_value` in case an attribute error occurs.
+        In case the function call is successful the function return value will
+        be returned.
+    """
+
+    try:
+        value = function(argument)
+    except AttributeError:
+        value = exception_value
+
+    return value
